package cd.casic.ci.api;

import cd.casic.ci.process.dto.req.aflManager.AflManagerReq;
import cd.casic.ci.process.dto.resp.aflManager.AflCrashesInfoResp;
import cd.casic.ci.process.dto.resp.aflManager.AflInfoResp;
import cd.casic.ci.process.dto.resp.aflManager.SeedsCountResp;
import cd.casic.ci.process.process.service.aflManager.AflCrashesInfoService;
import cd.casic.ci.process.process.service.aflManager.AflInfoService;
import cd.casic.ci.process.process.service.aflManager.AflSeedInfoService;
import cd.casic.ci.process.util.SftpUploadUtil;
import cd.casic.framework.commons.pojo.CommonResult;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author HopeLi
 * @version v1.0
 * @ClassName AflInfoController
 * @Date: 2025/7/1 9:03
 * @Description:
 */
@RestController
@RequestMapping("/aflManager")
public class AflManagerController {

    @Resource
    private AflInfoService aflInfoService;

    @Resource
    private AflCrashesInfoService aflCrashesInfoService;

    @Resource
    private AflSeedInfoService aflSeedInfoService;

    @PostMapping(path="/saveAflInfo")
    public CommonResult<String> saveAflInfo(@RequestBody @Valid AflManagerReq req) throws SftpUploadUtil.SftpUploadException {

        String groupIdentifier = aflInfoService.saveAflInfo(req);

        return CommonResult.success(groupIdentifier);
    }


    @PostMapping(path="/findAflInfo")
    public CommonResult<AflInfoResp> findAflInfo(@RequestBody @Valid AflManagerReq req) throws SftpUploadUtil.SftpUploadException {

        AflInfoResp resp = aflInfoService.findAflInfo(req);

        return CommonResult.success(resp);
    }


    @PostMapping(path="/findAflInfoList")
    public CommonResult<List<AflInfoResp>> findAflInfoList(@RequestBody @Valid AflManagerReq req){

        List<AflInfoResp> respList = aflInfoService.findPipelineList(req);

        return CommonResult.success(respList);
    }


    @PostMapping(path="/saveAflCrashesInfo")
    public CommonResult<String> saveAflCrashesInfo(@RequestBody @Valid AflManagerReq req) throws SftpUploadUtil.SftpUploadException {

        String groupIdentifier = aflCrashesInfoService.saveAflCrashesInfo(req);

        return CommonResult.success(groupIdentifier);
    }


    @PostMapping(path="/findAflCrashesInfoList")
    public CommonResult<List<AflCrashesInfoResp>> findAflCrashesInfoList(@RequestBody @Valid AflManagerReq req){

        List<AflCrashesInfoResp> respList = aflCrashesInfoService.findPipelineList(req);

        return CommonResult.success(respList);
    }


    @PostMapping(path="/findSeedsCount")
    public CommonResult<List<SeedsCountResp>> findSeedsCount(@RequestBody @Valid AflManagerReq req) throws SftpUploadUtil.SftpUploadException {

        List<SeedsCountResp> seedsCount = aflSeedInfoService.findSeedsCount(req);

        return CommonResult.success(seedsCount);
    }


    @PostMapping(path="/saveAflSeedInfo")
    public CommonResult<Void> saveAflSeedInfo(@RequestBody @Valid AflManagerReq req) throws SftpUploadUtil.SftpUploadException {

        aflSeedInfoService.saveAflSeedInfo(req);

        return CommonResult.success();
    }
}
